import { supabase } from '@/lib/supabase/client';
import { AuthError } from '@supabase/supabase-js';

export async function signIn(email: string, password: string, rememberMe: boolean) {
  try {
    const { data, error } = await supabase.auth.signInWithPassword({
      email,
      password,
    });

    if (error) throw error;

    if (rememberMe) {
      await supabase.auth.setSession({
        access_token: data.session.access_token,
        refresh_token: data.session.refresh_token,
      });
    }

    return { user: data.user, session: data.session };
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}

export async function signUp(email: string, password: string, fullName: string) {
  try {
    const { data, error } = await supabase.auth.signUp({
      email,
      password,
      options: {
        data: {
          full_name: fullName,
        },
        emailRedirectTo: `${window.location.origin}/auth/callback`,
      },
    });

    if (error) throw error;
    return { user: data.user, session: data.session };
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}

export async function signOut() {
  try {
    const { error } = await supabase.auth.signOut();
    if (error) throw error;
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}

export async function resetPassword(email: string) {
  try {
    const { error } = await supabase.auth.resetPasswordForEmail(email, {
      redirectTo: `${window.location.origin}/auth/reset-password`,
    });

    if (error) throw error;
  } catch (error) {
    throw handleAuthError(error as AuthError);
  }
}

function handleAuthError(error: AuthError) {
  console.error('Auth error:', error);
  return {
    message: getErrorMessage(error),
    status: error.status || 500,
  };
}

function getErrorMessage(error: AuthError): string {
  switch (error.message) {
    case 'Invalid login credentials':
      return 'Invalid email or password';
    case 'Email not confirmed':
      return 'Please verify your email address';
    case 'Email already registered':
      return 'An account with this email already exists';
    default:
      return error.message || 'An error occurred during authentication';
  }
}